@@ -104,6 +104,7 @@ uid_t	getuid();
 sig_t	lostpeer();
 off_t	restart_point = 0;
 unsigned long socks_bind_remoteAddr;		/* Socks */
+int	pasvmode = 0;
 
 extern char *strerror();
 extern int connected, errno;
@@ -131,13 +132,13 @@ int h_errno;		/* In some version of SunOS this is necessary */
  * herror --
  *	print the error indicated by the h_errno value.
  */
-#if defined(AIX_PS2)
+#if defined(AIX_PS2) || defined(BIND_RESOLVER)
 void herror(s)
       const char *s;
 #else /* #if AIX_PS2 not defined */
 herror(s)
       char *s;
-#endif /* #if defined(AIX_PS2) */
+#endif /* #if defined(AIX_PS2) || defined(BIND_RESOLVER) */
 {
 	if (s && *s) {
 		fprintf(stderr, "%s: ", s);
@@ -157,6 +158,7 @@ herror(s)
 
 #endif /* !defined(SVR3) && !defined(BIND_RESOLVER) && !defined(LINUX) */
 
+
 char *
 hookup(host, port)
 	char *host;
@@ -1130,6 +1132,8 @@ abort:
 	(void) signal(SIGINT, oldintr);
 }
 
+
+
 /*
  * Need to start a listen on the data channel before we send the command,
  * otherwise the server's connect may fail.
@@ -1139,8 +1143,47 @@ initconn()
 	register char *p, *a;
 	int result, len, tmpno = 0;
 	int on = 1;
+#if defined(TRY_PASV) || defined(NO_RBIND)
+	unsigned int h0, h1, h2, h3, p0, p1;
+	unsigned int ipaddr;
+	unsigned short ipport;
 
+	data = socket(AF_INET, SOCK_STREAM, 0);
+	if (data < 0) {
+		perror("ftp: socket");
+		return (1);
+	}
+	if (options & SO_DEBUG &&
+	    setsockopt(data, SOL_SOCKET, SO_DEBUG, (char *)&on, sizeof (on)) < 0)
+		perror("ftp: setsockopt (ignored)");
+	if ((command("PASV") == COMPLETE) && (sscanf(pasv,
+		"%d,%d,%d,%d,%d,%d", &h0, &h1, &h2, &h3, &p0, &p1) == 6)) {
+		ipaddr = (((h0 << 8) + h1 << 8) + h2 << 8) + h3;
+		ipport = (p0 << 8) + p1;
+		data_addr.sin_family = AF_INET;
+		data_addr.sin_addr.s_addr = htonl(ipaddr);
+		data_addr.sin_port = htons(ipport);
+		if (connect(data, (struct sockaddr *)&data_addr, sizeof(data_addr)) != -1) {
+#if defined(IP_TOS) && defined(IPTOS_THROUGHPUT)
+			on = IPTOS_THROUGHPUT;
+			if (setsockopt(data, IPPROTO_IP, IP_TOS, (char *)&on, sizeof(int)) < 0)
+				perror("ftp: setsockopt TOS (ignored)");
+#endif
+			pasvmode = 1;
+			return 0;
+		}
+	}
+#if defined(NO_RBIND)
+	printf("Attempt to set this FTP server in PASV mode failed\n");
+	close(data);
+	return 1;
+#endif /* #if defined(NO_RBIND) */
+
+#endif /* #if defined(TRY_PASV) || defined(NO_RBIND) */
+
+#if !defined(NO_RBIND)
 noport:
+	pasvmode = 0;
 	data_addr = myctladdr;
 	if (sendport)
 		data_addr.sin_port = 0;	/* let system pick one */ 
@@ -1200,6 +1243,9 @@ bad:
 	if (tmpno)
 		sendport = 1;
 	return (1);
+
+#endif /* #if !defined(NO_RBIND) */
+
 }
 
 FILE *
@@ -1209,6 +1255,9 @@ dataconn(lmode)
 	struct sockaddr_in from;
 	int s, fromlen = sizeof (from), tos;
 
+	if (pasvmode)
+		return fdopen(data, lmode);
+
 	s = accept(data, (struct sockaddr *) &from, &fromlen);
 	if (s < 0) {
 		perror("ftp: accept");
