@@ -20,9 +20,13 @@
 static char sccsid[] = "@(#)commands.c	5.4 (Berkeley) 3/1/91";
 #endif /* not lint */
 
+#if defined(SOCKS)
+#define connect Rconnect
+#endif
+
 #if	defined(unix)
 #include <sys/param.h>
-#ifdef	CRAY
+#if defined(CRAY) || defined(SCO) || defined(ISC)
 #include <sys/types.h>
 #endif
 #include <sys/file.h>
@@ -41,6 +45,9 @@ static char sccsid[] = "@(#)commands.c	5.4 (Berkeley) 3/1/91";
 #include <pwd.h>
 #include <varargs.h>
 #include <errno.h>
+#if defined(ISC)
+#include <net/errno.h>
+#endif /* #if defined(ISC) */
 
 #include <arpa/telnet.h>
 
@@ -62,13 +69,29 @@ static char sccsid[] = "@(#)commands.c	5.4 (Berkeley) 3/1/91";
 #include <netinet/ip.h>
 #endif /* LINUX */
 
-#if defined(SOLARIS)
+#if defined(SOLARIS) || defined(_SEQUENT_)
 #include "bstring.h"
 #endif
 
+#if defined(AIX) || defined(DGUX)
+#undef IP_TOS
+#endif
+
 #ifndef       MAXHOSTNAMELEN
 #define       MAXHOSTNAMELEN 64
-#endif        MAXHOSTNAMELEN
+#endif        /* #ifndef MAXHOSTNAMELEN */
+
+#ifdef __alpha
+typedef unsigned int u_int32;
+#else
+typedef unsigned long u_int32;
+#endif
+
+/* >>> H.Naef, nexos ag */
+#if !defined(INADDR_NONE)
+#define INADDR_NONE (u_int32) 0xffffffff
+#endif /* !defined(INADDR_NONE) */
+/* <<< H.Naef, nexos ag */
 
 #if	defined(IPPROTO_IP) && defined(IP_TOS)
 int tos = -1;
@@ -846,7 +869,7 @@ toggle(argc, argv)
  */
 
 #ifdef	USE_TERMIO
-# if defined(SOLARIS) || defined(LINUX)
+# if defined(SOLARIS) || defined(LINUX) || defined(_SEQUENT_)
 struct termios new_tc = { 0 };
 # else
 struct termio new_tc = { 0 };
@@ -1386,7 +1409,11 @@ shell(argc, argv)
     char *argv[];
 {
     setcommandmode();
-    switch(vfork()) {
+#ifdef SCO
+	switch(fork()) {
+#else
+	switch(vfork()) {
+#endif
     case -1:
 	perror("Fork failed\n");
 	break;
@@ -2144,7 +2171,7 @@ ayt_status()
 #endif
 
 extern char *inet_ntoa();
-extern unsigned long inet_addr();
+extern u_int32 inet_addr();
 
     int
 tn(argc, argv)
@@ -2154,14 +2181,14 @@ tn(argc, argv)
     register struct hostent *host = 0;
     struct sockaddr_in sin;
     struct servent *sp = 0;
-    unsigned long temp;
+    u_int32 temp;
 #if	defined(IP_OPTIONS) && defined(IPPROTO_IP)
 #ifndef AIX
     char *srp = 0, *strrchr();
 #else
     char *srp = 0;
 #endif /* AIX */
-    unsigned long sourceroute(), srlen;
+    u_int32 sourceroute(), srlen;
 #endif
     char *cmd, *hostp = 0, *portp = 0, *user = 0;
 
@@ -2228,7 +2255,8 @@ tn(argc, argv)
 	    herror(srp);
 	    setuid(getuid());
 	    return 0;
-	} else if (temp == -1) {
+	/* } else if (temp == -1) { */
+	    } else if (temp == INADDR_NONE /* H.Naef, nexos ag */) {
 	    printf("Bad source route option: %s\n", hostp);
 	    setuid(getuid());
 	    return 0;
@@ -2239,7 +2267,8 @@ tn(argc, argv)
     } else {
 #endif
 	temp = inet_addr(hostp);
-	if (temp != (unsigned long) -1) {
+	/* if (temp != (u_int32) -1) { */
+	if (temp != INADDR_NONE /* H.Naef, nexos ag */) {
 	    sin.sin_addr.s_addr = temp;
 	    sin.sin_family = AF_INET;
 	    (void) strcpy(_hostname, hostp);
@@ -2332,11 +2361,7 @@ tn(argc, argv)
 		perror("setsockopt (SO_DEBUG)");
 	}
 
-#ifdef RTELNET
-	if (Rconnect(net, (struct sockaddr *)&sin, sizeof (sin)) < 0) {
-#else
 	if (connect(net, (struct sockaddr *)&sin, sizeof (sin)) < 0) {
-#endif
 #if	defined(h_addr)		/* In 4.3, this is a #define */
 	    if (host && host->h_addr_list[1]) {
 		int oerrno = errno;
@@ -2738,7 +2763,7 @@ cmdrc(m1, m2)
  *		pointed to by *cpp is.
  *	
  */
-	unsigned long
+	u_int32
 sourceroute(arg, cpp, lenp)
 	char	*arg;
 	char	**cpp;
@@ -2756,9 +2781,11 @@ sourceroute(arg, cpp, lenp)
 	 * at least 7 bytes for the option.
 	 */
 	if (cpp == NULL || lenp == NULL)
-		return((unsigned long)-1);
+		/* return((u_int32)-1); */
+		return(INADDR_NONE /* H.Naef, nexos ag */);
 	if (*cpp != NULL && *lenp < 7)
-		return((unsigned long)-1);
+		/* return((u_int32)-1); */
+		return(INADDR_NONE /* H.Naef, nexos ag */);
 	/*
 	 * Decide whether we have a buffer passed to us,
 	 * or if we need to use our own static buffer.
@@ -2785,7 +2812,8 @@ sourceroute(arg, cpp, lenp)
 		*lsrp++ = IPOPT_LSRR;
 
 	if (*cp != '@')
-		return((unsigned long)-1);
+		/* return((u_int32)-1); */
+		return(INADDR_NONE /* H.Naef, nexos ag */);
 
 	lsrp++;		/* skip over length, we'll fill it in later */
 	*lsrp++ = 4;
@@ -2813,7 +2841,8 @@ sourceroute(arg, cpp, lenp)
 		if (!c)
 			cp2 = 0;
 
-		if ((tmp = inet_addr(cp)) != -1) {
+		/* if ((tmp = inet_addr(cp)) != -1) { */
+		if ((tmp = inet_addr(cp)) != INADDR_NONE /* H.Naef, nexos ag */) {
 			sin_addr.s_addr = tmp;
 		} else if (host = gethostbyname(cp)) {
 #if	defined(h_addr)
@@ -2836,12 +2865,14 @@ sourceroute(arg, cpp, lenp)
 		 * Check to make sure there is space for next address
 		 */
 		if (lsrp + 4 > lsrep)
-			return((unsigned long)-1);
+			/* return((u_int32)-1); */
+			return(INADDR_NONE /* H.Naef, nexos ag */);
 	}
 	if ((*(*cpp+IPOPT_OLEN) = lsrp - *cpp) <= 7) {
 		*cpp = 0;
 		*lenp = 0;
-		return((unsigned long)-1);
+		/* return((u_int32)-1); */
+		return(INADDR_NONE /* H.Naef, nexos ag */);
 	}
 	*lsrp++ = IPOPT_NOP; /* 32 bit word align it */
 	*lenp = lsrp - *cpp;
